//
//  Kmpg
// 
//  Copyright (C) 1997 Bjarni Ivarsson
//  email: Bjarni.Ivarsson@swipnet.se
// 
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//

#ifndef PLAYLIST_H
#define PLAYLIST_H

//#include <qdialog.h>
#include <qlistbox.h>
#include <qgrpbox.h>
#include <qfiledlg.h>

#include <kapp.h>
#include <drag.h>
#include <kurl.h>

#include "playlistmgr.h"

class PlaylistItem : public QListBoxItem 
{
   public:
      PlaylistItem( KURL );
      virtual void setPlayed( bool pl ) { _played = pl; };
      virtual bool isPlayed() { return _played; };
      virtual KURL getUrl() { return _url; };   
      
   protected:
      virtual void paint( QPainter* );
      virtual int height( const QListBox* ) const;
      virtual int width( const QListBox* ) const;
   private:
      KURL _url;
      bool _played;
};

class PlaylistBox : public QListBox
{
      Q_OBJECT
   public:
      PlaylistBox( QWidget * parent=0, const char * name=0, WFlags f=0 );
   public slots:
      // These slots are connected to signals from
      // the playlist manager
      void doClear();
      void doInsert( int, QString );
      void doUpdate( int, QString );
      void doRemove( int );
      void doMoveUp( int );
      void doMoveDown( int );
      void doSetPlayed( int, bool );
      void doSetAllPlayed( bool );
      void doTrackSelected( int );
};

class Playlist : public QDialog 
{
      Q_OBJECT
   public:
      Playlist( PlaylistMgr* mgr );
      ~Playlist();
      virtual void readProperties( KConfig* );
      virtual void saveProperties( KConfig* );
   private:
      virtual void resizeEvent( QResizeEvent* );
   public slots:
      // Slots connected to buttons in dialog
      void slotShow();
      void slotClose();
      void slotLoadPlaylist();
      void slotSavePlaylist();
      void slotAddPlaylist();
      void slotAddMPEG();
      void slotUp();
      void slotDown();
      void slotDelMPEG();

      // Drag'N'Drop callback
      void slotDrop(KDNDDropZone*);
   private:
      PlaylistMgr *playlistMgr;
      PlaylistBox *listbox;
      QWidget *buttonPanel;  
};

#endif
